@@ -1,7 +1,7 @@
 /* Header for poll(2) emulation
    Contributed by Paolo Bonzini.
 
-   Copyright 2001-2003, 2007, 2009-2022 Free Software Foundation, Inc.
+   Copyright 2001-2003, 2007, 2009-2023 Free Software Foundation, Inc.
 
    This file is part of gnulib.
 
@@ -33,6 +33,11 @@
 #ifndef _@GUARD_PREFIX@_POLL_H
 #define _@GUARD_PREFIX@_POLL_H
 
+/* This file uses GNULIB_POSIXCHECK, HAVE_RAW_DECL_*.  */
+#if !_GL_CONFIG_H_INCLUDED
+ #error "Please include config.h first."
+#endif
+
 /* On native Windows, get the 'struct pollfd' type and the POLL* macro
    definitions before we override them.  mingw defines them in <winsock2.h>
    if _WIN32_WINNT >= 0x0600.  */
