@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2001-2022 Free Software Foundation, Inc.
+  Copyright (C) 2001-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -32,7 +32,8 @@
 #include <icmp.h>
 
 int
-icmp_timestamp_encode (unsigned char * buffer, size_t bufsize, int ident, int seqno)
+icmp_timestamp_encode (unsigned char *buffer, size_t bufsize, int ident,
+		       int seqno)
 {
   icmphdr_t *icmp;
   struct timeval tv;
