@@ -1,6 +1,5 @@
 /*
-  Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
-  2018, 2019, 2020, 2021 Free Software Foundation, Inc.
+  Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -23,8 +22,7 @@
 
 /* Sometimes we do not know exact author names for a given utility. In such
    cases we use the following "author list": */
-const char *default_program_authors[] =
-  {
-    "many authors",
-    NULL
-  };
+const char *default_program_authors[] = {
+  "many authors",
+  NULL
+};
