@@ -1,5 +1,5 @@
 /* localhost.c - A slightly more convenient wrapper for gethostname
-  Copyright (C) 1996-2022 Free Software Foundation, Inc.
+  Copyright (C) 1996-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -89,8 +89,7 @@ localhost (void)
 	{
 	  /* Back resolving as official host name.  */
 	  rc = getnameinfo (res->ai_addr, res->ai_addrlen,
-			    fqdn, sizeof (fqdn), NULL, 0,
-			    NI_NAMEREQD);
+			    fqdn, sizeof (fqdn), NULL, 0, NI_NAMEREQD);
 	  if (!rc)
 	    {
 	      free (buf);
