@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1997-2022 Free Software Foundation, Inc.
+  Copyright (C) 1997-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -342,8 +342,7 @@ mk_cred (dec_rep, etype, key, sender_addr, recv_addr, outbuf)
 
   krb5_use_cstype (&eblock, etype);
   ret_cred.enc_part.ciphertext.length = krb5_encrypt_size (scratch->length,
-							   eblock.
-							   crypto_entry);
+							   eblock.crypto_entry);
   /* add padding area, and zero it */
   if (!(scratch->data = realloc (scratch->data,
 				 ret_cred.enc_part.ciphertext.length)))
