@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2001-2022 Free Software Foundation, Inc.
+  Copyright (C) 2001-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -64,7 +64,8 @@ ping_address (char *hostname)
     error (EXIT_FAILURE, 0, "unknown host");
 
   printf ("PING %s (%s): sending address mask request\n",
-	  ping->ping_hostname, inet_ntoa (ping->ping_dest.ping_sockaddr.sin_addr));
+	  ping->ping_hostname,
+	  inet_ntoa (ping->ping_dest.ping_sockaddr.sin_addr));
 
   return ping_run (ping, address_finish);
 }
@@ -73,7 +74,7 @@ ping_address (char *hostname)
 int
 recv_address (int code, void *closure,
 	      struct sockaddr_in *dest, struct sockaddr_in *from,
-	      struct ip *ip, icmphdr_t * icmp, int datalen)
+	      struct ip *ip, icmphdr_t *icmp, int datalen)
 {
   switch (code)
     {
@@ -92,8 +93,7 @@ void
 print_address (int dupflag, void *closure MAYBE_UNUSED,
 	       struct sockaddr_in *dest MAYBE_UNUSED,
 	       struct sockaddr_in *from,
-	       struct ip *ip MAYBE_UNUSED,
-	       icmphdr_t * icmp, int datalen)
+	       struct ip *ip MAYBE_UNUSED, icmphdr_t *icmp, int datalen)
 {
   struct in_addr addr;
 
