@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2001-2020 Free Software Foundation, Inc.
+  Copyright (C) 2001-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -38,13 +38,13 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <errno.h>
-#include <unused-parameter.h>
+#include <attribute.h>
 
 #include <ping.h>
 #include <ping_impl.h>
 
 int
-ping_router (char *hostname _GL_UNUSED_PARAMETER)
+ping_router (char *hostname MAYBE_UNUSED)
 {
   return 0;
 }
