@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2022 Free Software Foundation, Inc.
+  Copyright (C) 1995-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -90,7 +90,7 @@
 
 /* Some systems define PKTSIZE in <arpa/tftp.h>.  */
 #ifndef PKTSIZE
-#define PKTSIZE    SEGSIZE+4
+# define PKTSIZE    SEGSIZE+4
 #endif
 
 char ackbuf[PKTSIZE];
@@ -112,8 +112,8 @@ static int maxtimeout = 5 * TIMEOUT;
 
 static struct sockaddr_storage peeraddr;	/* filled in by main */
 static socklen_t peerlen;
-static int f = -1;				/* the opened socket */
-static int port; /* Port number in host byte order of the server. */
+static int f = -1;		/* the opened socket */
+static int port;		/* Port number in host byte order of the server. */
 static int trace;
 static int verbose;
 static int connected;
@@ -206,6 +206,7 @@ static struct argp_option argp_options[] = {
 };
 
 char *hostport_argv[3] = { "connect" };
+
 int hostport_argc = 1;
 
 static in_port_t
@@ -229,11 +230,11 @@ set_port (struct sockaddr_storage *ss, in_port_t port)
   switch (ss->ss_family)
     {
     case AF_INET6:
-      ((struct sockaddr_in6 *) ss)->sin6_port = htons(port);
+      ((struct sockaddr_in6 *) ss)->sin6_port = htons (port);
       break;
     case AF_INET:
     default:
-      ((struct sockaddr_in *) ss)->sin_port = htons(port);
+      ((struct sockaddr_in *) ss)->sin_port = htons (port);
       break;
     }
 }
@@ -246,7 +247,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
 {
   switch (key)
     {
-    case 'v':		/* Verbose.  */
+    case 'v':			/* Verbose.  */
       verbose++;
       break;
 
@@ -265,7 +266,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
 }
 
 static struct argp argp =
-  {argp_options, parse_opt, args_doc, doc, NULL, NULL, NULL};
+  { argp_options, parse_opt, args_doc, doc, NULL, NULL, NULL };
 
 int
 main (int argc, char *argv[])
@@ -369,7 +370,7 @@ resolve_name (char *name)
       ss.ss_len = ai->ai_addrlen;
 #endif
       if (bind (f, (struct sockaddr *) &ss, ai->ai_addrlen))
-        {
+	{
 	  close (f);
 	  f = -1;
 	  continue;
@@ -468,15 +469,14 @@ struct modes
 {
   char *m_name;
   char *m_mode;
-} modes[] =
-  {
-    {"ascii", "netascii"},
-    {"netascii", "netascii"},
-    {"binary", "octet"},
-    {"image", "octet"},
-    {"octet", "octet"},
-    {0, 0}
-  };
+} modes[] = {
+  {"ascii", "netascii"},
+  {"netascii", "netascii"},
+  {"binary", "octet"},
+  {"image", "octet"},
+  {"octet", "octet"},
+  {0, 0}
+};
 
 void
 modecmd (int argc, char *argv[])
@@ -567,10 +567,10 @@ put (int argc, char *argv[])
       cp = argv[argc - 1];
       /* Is host string escaped using square brackets?  */
       if (cp[0] == '[')
-	{ /* Locate far end.  */
+	{			/* Locate far end.  */
 	  cp = strchr (cp, ']');
 	  if (cp == NULL)
-	    return;	/* Unpaired bracket.  Fail!  */
+	    return;		/* Unpaired bracket.  Fail!  */
 
 	  /* Erase far end and capture valid host string.  */
 	  *cp = 0;
@@ -593,7 +593,7 @@ put (int argc, char *argv[])
 	  /* Test whether host string lacks content.
 	   * Then the host string will be ignored.  */
 	  if (strlen (cp) == 0)
-	    cp = NULL;	/* Invalidate host name string.  */
+	    cp = NULL;		/* Invalidate host name string.  */
 	}
       /* If a remote host was stated, resolve it!  */
       if (cp != NULL && resolve_name (cp) != RESOLVE_OK)
@@ -688,7 +688,7 @@ get (int argc, char *argv[])
 	  ++src;
 	}
       else
-	{ /* Parse the host name string; remove square brackets.  */
+	{			/* Parse the host name string; remove square brackets.  */
 	  cp = argv[n];
 
 	  if (cp[0] == '[')
@@ -705,7 +705,7 @@ get (int argc, char *argv[])
 		}
 	    }
 	  else
-	    { /* No escaping; break string at first colon.  */
+	    {			/* No escaping; break string at first colon.  */
 	      *src++ = 0;
 	    }
 	  if (cp != NULL && resolve_name (cp) != RESOLVE_OK)
@@ -1266,18 +1266,17 @@ struct errmsg
 {
   int e_code;
   const char *e_msg;
-} errmsgs[] =
-  {
-    {EUNDEF, "Undefined error code"},
-    {ENOTFOUND, "File not found"},
-    {EACCESS, "Access violation"},
-    {ENOSPACE, "Disk full or allocation exceeded"},
-    {EBADOP, "Illegal TFTP operation"},
-    {EBADID, "Unknown transfer ID"},
-    {EEXISTS, "File already exists"},
-    {ENOUSER, "No such user"},
-    {-1, 0}
-  };
+} errmsgs[] = {
+  {EUNDEF, "Undefined error code"},
+  {ENOTFOUND, "File not found"},
+  {EACCESS, "Access violation"},
+  {ENOSPACE, "Disk full or allocation exceeded"},
+  {EBADOP, "Illegal TFTP operation"},
+  {EBADID, "Unknown transfer ID"},
+  {EEXISTS, "File already exists"},
+  {ENOUSER, "No such user"},
+  {-1, 0}
+};
 
 /*
  * Send a nak packet (error message).
