@@ -1,8 +1,5 @@
 /*
-  Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
-  2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software Foundation,
-  Inc.
+  Copyright (C) 1995-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -140,7 +137,7 @@ get_addrs (char *my_machine_name, char *his_machine_name)
 
       /* Attempt binding to this local address.  */
       if (bind (f, ai->ai_addr, ai->ai_addrlen))
-        {
+	{
 	  close (f);
 	  f = -1;
 	  continue;
