@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015,
-  2016, 2017, 2018, 2019, 2020, 2021 Free Software Foundation, Inc.
+  Copyright (C) 1996-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -21,7 +19,7 @@
 #include <config.h>
 
 #include <intalkd.h>
-#include "unused-parameter.h"
+#include "attribute.h"
 
 typedef struct request_table table_t;
 
@@ -35,7 +33,7 @@ struct request_table
 static table_t *table;
 
 static void
-table_delete (table_t * ptr)
+table_delete (table_t *ptr)
 {
   table_t *t;
 
@@ -53,7 +51,7 @@ table_delete (table_t * ptr)
    Evil) */
 
 static CTL_MSG *
-lookup_request (CTL_MSG * request,
+lookup_request (CTL_MSG *request,
 		int (*comp) (table_t *, CTL_MSG *, time_t *))
 {
   table_t *ptr;
@@ -92,8 +90,7 @@ lookup_request (CTL_MSG * request,
 }
 
 static int
-fuzzy_comp (table_t * ptr, CTL_MSG * request,
-	    time_t * unused _GL_UNUSED_PARAMETER)
+fuzzy_comp (table_t *ptr, CTL_MSG *request, time_t *unused MAYBE_UNUSED)
 {
   if (ptr->request.type == LEAVE_INVITE
       && strcmp (request->l_name, ptr->request.r_name) == 0
@@ -105,13 +102,13 @@ fuzzy_comp (table_t * ptr, CTL_MSG * request,
 /* Look in the table for an invitation that matches the current
    request looking for an invitation */
 CTL_MSG *
-find_match (CTL_MSG * request)
+find_match (CTL_MSG *request)
 {
   return lookup_request (request, fuzzy_comp);
 }
 
 static int
-exact_comp (table_t * ptr, CTL_MSG * request, time_t * now)
+exact_comp (table_t *ptr, CTL_MSG *request, time_t *now)
 {
   if (request->type == ptr->request.type
       && request->pid == ptr->request.pid
@@ -128,7 +125,7 @@ exact_comp (table_t * ptr, CTL_MSG * request, time_t * now)
    one as find_match does */
 
 CTL_MSG *
-find_request (CTL_MSG * request)
+find_request (CTL_MSG *request)
 {
   return lookup_request (request, exact_comp);
 }
@@ -149,7 +146,7 @@ new_id (void)
 }
 
 int
-insert_table (CTL_MSG * request, CTL_RESPONSE * response)
+insert_table (CTL_MSG *request, CTL_RESPONSE *response)
 {
   table_t *ptr;
 
