@@ -1,8 +1,5 @@
 /*
-  Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
-  2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software Foundation,
-  Inc.
+  Copyright (C) 1995-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -64,7 +61,7 @@
 #include <errno.h>
 #include <arpa/telnet.h>
 #include <sys/select.h>
-#include <unused-parameter.h>
+#include <attribute.h>
 
 #include "ring.h"
 
@@ -85,6 +82,7 @@ int tout,			/* Output file descriptor */
 struct tchars otc = { 0 }, ntc = { 0 };
 struct ltchars oltc = { 0 }, nltc = { 0 };
 struct sgttyb ottyb = { 0 }, nttyb = { 0 };
+
 int olmode = 0;
 # define cfgetispeed(ptr)	(ptr)->sg_ispeed
 # define cfgetospeed(ptr)	(ptr)->sg_ospeed
@@ -92,6 +90,7 @@ int olmode = 0;
 
 #else /* USE_TERMIO */
 struct termio old_tc = { 0 };
+
 extern struct termio new_tc;
 
 # ifndef TCSANOW
@@ -117,7 +116,7 @@ extern struct termio new_tc;
 #  else
 #   define cfgetispeed(ptr)	cfgetospeed(ptr)
 #  endif
-# endif	/* TCSANOW */
+# endif/* TCSANOW */
 # ifdef	sysV88
 #  define TIOCFLUSH TC_PX_DRAIN
 # endif
@@ -183,7 +182,8 @@ extern int kludgelinemode;
  *	1	Do add this character
  */
 
-extern void xmitAO (void), xmitEL (void), xmitEC (void), intp (void), sendbrk (void);
+extern void xmitAO (void), xmitEL (void), xmitEC (void), intp (void),
+sendbrk (void);
 
 int
 TerminalSpecialChars (int c)
@@ -744,7 +744,7 @@ TerminalNewMode (register int f)
       }
 # else
       sigsetmask (sigblock (0) & ~(1 << (SIGTSTP - 1)));
-# endif	/* HAVE_SIGACTION */
+# endif/* HAVE_SIGACTION */
 #endif /* SIGTSTP */
 #ifndef USE_TERMIO
       ltc = oltc;
@@ -834,32 +834,31 @@ struct termspeeds
 {
   long speed;
   long value;
-} termspeeds[] =
-  {
-    {0, B0},
-    {50, B50},
-    {75, B75},
-    {110, B110},
-    {134, B134},
-    {150, B150},
-    {200, B200},
-    {300, B300},
-    {600, B600},
-    {1200, B1200},
-    {1800, B1800},
-    {2400, B2400},
-    {4800, B4800},
-    {7200, B7200},
-    {9600, B9600},
-    {14400, B14400},
-    {19200, B19200},
-    {28800, B28800},
-    {38400, B38400},
-    {57600, B57600},
-    {115200, B115200},
-    {230400, B230400},
-    {-1, B230400}
-  };
+} termspeeds[] = {
+  {0, B0},
+  {50, B50},
+  {75, B75},
+  {110, B110},
+  {134, B134},
+  {150, B150},
+  {200, B200},
+  {300, B300},
+  {600, B600},
+  {1200, B1200},
+  {1800, B1800},
+  {2400, B2400},
+  {4800, B4800},
+  {7200, B7200},
+  {9600, B9600},
+  {14400, B14400},
+  {19200, B19200},
+  {28800, B28800},
+  {38400, B38400},
+  {57600, B57600},
+  {115200, B115200},
+  {230400, B230400},
+  {-1, B230400}
+};
 #endif /* DECODE_BAUD */
 
 void
@@ -942,7 +941,7 @@ NetSetPgrp (int fd)
  */
 
 void
-deadpeer (int sig _GL_UNUSED_PARAMETER)
+deadpeer (int sig MAYBE_UNUSED)
 {
   setcommandmode ();
   longjmp (peerdied, -1);
@@ -950,7 +949,7 @@ deadpeer (int sig _GL_UNUSED_PARAMETER)
 
 
 void
-intr (int sig _GL_UNUSED_PARAMETER)
+intr (int sig MAYBE_UNUSED)
 {
   if (localchars)
     {
@@ -963,7 +962,7 @@ intr (int sig _GL_UNUSED_PARAMETER)
 
 
 void
-intr2 (int sig _GL_UNUSED_PARAMETER)
+intr2 (int sig MAYBE_UNUSED)
 {
   if (localchars)
     {
@@ -979,7 +978,7 @@ intr2 (int sig _GL_UNUSED_PARAMETER)
 
 #ifdef	SIGTSTP
 void
-susp (int sig _GL_UNUSED_PARAMETER)
+susp (int sig MAYBE_UNUSED)
 {
   if ((rlogin != _POSIX_VDISABLE) && rlogin_susp ())
     return;
@@ -990,7 +989,7 @@ susp (int sig _GL_UNUSED_PARAMETER)
 
 #ifdef	SIGWINCH
 void
-sendwin (int sig _GL_UNUSED_PARAMETER)
+sendwin (int sig MAYBE_UNUSED)
 {
   if (connected)
     {
@@ -1001,7 +1000,7 @@ sendwin (int sig _GL_UNUSED_PARAMETER)
 
 #ifdef	SIGINFO
 void
-ayt (int sig _GL_UNUSED_PARAMETER)
+ayt (int sig MAYBE_UNUSED)
 {
   if (connected)
     sendayt ();
@@ -1085,27 +1084,27 @@ process_rings (int netin, int netout, int netex, int ttyin, int ttyout,
     {
       FD_SET (net, &obits);
       if (net > nfds)
-        nfds = net;
+	nfds = net;
     }
   if (ttyout)
     {
       FD_SET (tout, &obits);
       if (tout > nfds)
-        nfds = tout;
+	nfds = tout;
     }
 #if defined TN3270
   if (ttyin)
     {
       FD_SET (tin, &ibits);
       if (tin > nfds)
-        nfds = tin;
+	nfds = tin;
     }
 #else /* defined(TN3270) */
   if (ttyin)
     {
       FD_SET (tin, &ibits);
       if (tin > nfds)
-        nfds = tin;
+	nfds = tin;
     }
 #endif /* defined(TN3270) */
 #if defined TN3270
@@ -1113,23 +1112,23 @@ process_rings (int netin, int netout, int netex, int ttyin, int ttyout,
     {
       FD_SET (net, &ibits);
       if (net > nfds)
-        nfds = net;
+	nfds = net;
     }
 #else /* !defined(TN3270) */
   if (netin)
     {
       FD_SET (net, &ibits);
       if (net > nfds)
-        nfds = net;
+	nfds = net;
     }
 #endif /* !defined(TN3270) */
   if (netex)
     {
       FD_SET (net, &xbits);
       if (net > nfds)
-        nfds = net;
+	nfds = net;
     }
-  if ((c = select (nfds+1, &ibits, &obits, &xbits,
+  if ((c = select (nfds + 1, &ibits, &obits, &xbits,
 		   (poll == 0) ? (struct timeval *) 0 : &TimeValue)) < 0)
     {
       if (c == -1)
@@ -1274,7 +1273,7 @@ process_rings (int netin, int netout, int netex, int ttyin, int ttyout,
 		  /*
 		   * Bogosity.  We have to do the read
 		   * to clear the atmark to get out of
-		   * an infinate loop.
+		   * an infinite loop.
 		   */
 		  i = read (net, netiring.supply + c, canread - c);
 		  if (i > 0)
@@ -1317,8 +1316,8 @@ process_rings (int netin, int netout, int netex, int ttyin, int ttyout,
   if (FD_ISSET (tin, &ibits))
     {
       FD_CLR (tin, &ibits);
-      c = TerminalRead ((char *)ttyiring.supply,
-                        ring_empty_consecutive (&ttyiring));
+      c = TerminalRead ((char *) ttyiring.supply,
+			ring_empty_consecutive (&ttyiring));
       if (c < 0 && errno == EIO)
 	c = 0;
       if (c < 0 && errno == EWOULDBLOCK)
