@@ -1,5 +1,5 @@
 /* identify -- Probe system and report characteristica.
-  Copyright (C) 2013-2022 Free Software Foundation, Inc.
+  Copyright (C) 2013-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -56,7 +56,7 @@
   if (tc.a & b) printf (" %s", name);
 
 void
-do_termcap(void)
+do_termcap (void)
 {
   int pty, tty;
   struct termios tc;
@@ -64,8 +64,7 @@ do_termcap(void)
   pty = openpty (&pty, &tty, NULL, NULL, NULL);
   if (pty < 0)
     {
-      fprintf (stderr, "openpt: errno = %d, %s\n",
-	       errno, strerror (errno));
+      fprintf (stderr, "openpt: errno = %d, %s\n", errno, strerror (errno));
       return;
     }
 
@@ -115,19 +114,21 @@ do_termcap(void)
     case TAB2:
       putchar ('2');
       break;
-#  endif /* TAB2 */
+#  endif
+      /* TAB2 */
 #  ifdef TAB1
     case TAB1:
       putchar ('1');
       break;
-#  endif /* TAB1 */
+#  endif
+      /* TAB1 */
     case TAB0:
       putchar ('0');
       break;
     }
-# elif defined OXTABS /* !TABDLY */
+# elif defined OXTABS		/* !TABDLY */
   test_flag (c_oflag, OXTABS, "OXTABS");
-# endif /* OXTABS */
+# endif/* OXTABS */
 
   puts ("");
 
@@ -156,6 +157,7 @@ do_termcap(void)
 
   return;
 }
+
 # undef test_flag
 #endif /* HAVE_TCGETATTR */
 
@@ -174,8 +176,7 @@ main (void)
     }
 
   /* Identify the hardware.  */
-  printf ("Running system: %s, %s\n",
-	  uts.sysname, uts.machine);
+  printf ("Running system: %s, %s\n", uts.sysname, uts.machine);
   printf (" Variant: %s\n", uts.release);
   printf (" Variant: %s\n", uts.version);
   puts ("");
@@ -235,7 +236,7 @@ main (void)
 	  sizeof (su.sun_path));
 
 #if HAVE_TCGETATTR
-  puts("");
+  puts ("");
   do_termcap ();
 #endif
 
